Module source

Module source 

Source representation for tables whose FROM clause may be a sub-SELECT.

A backend’s TableSource::Source is either a plain String (most backends) or SelectSource<S> — the shared enum used by every backend whose Select can express FROM (subquery) (SQLite, PostgreSQL, MySQL, SurrealDB).

Enums

SelectSource
The source of a table: a named table, or an arbitrary query used as a derived (sub-SELECT) source.

Traits

SelectSeed
Applies a source to a freshly-created Select.