Module table_source

Module table_source 

Traits

TableSource
Trait for table data sources that defines column type separate from execution TableSource represents a data source that can create and manage tables