Type-erased table wrapper with downcasting support
AnyTable provides a way to store tables of different types uniformly
while preserving the ability to recover the concrete type through downcasting.
Tables whose value/id types differ from serde_json::Value/String can still
be wrapped via AnyTable::from_table as long as the value type implements
Into<Value> + From<Value> and the id type implements Display + From<String>.
Structs
- AnyTable
- Type-erased table that can be downcast to concrete
Table<T, E>Works with AnyRecord (which uses serde_json::Value)