pub enum ColumnFlag {
Mandatory,
Hidden,
IdField,
TitleField,
Searchable,
}Expand description
Column flags that define behavior and properties of columns.
Variants
Mandatory
Mandatory will require read/write operations to always have value for this field, it cannot be missing
Hidden
Hidden columns should be excluded from UI display
IdField
IdField marks this column as the primary identifier for the table
TitleField
TitleField marks this column as the display title/name for records
Searchable
Searchable marks this column as searchable in text searches