Module references

Module references 

Table reference system for relationships between tables.

The Reference trait describes a relationship (field names, target factory). Resolution (building conditions) happens in Table::get_ref_as.

Three concrete types:

  • HasOne — foreign key on source table (e.g. Client.bakery_id → Bakery)
  • HasMany — foreign key on target table (e.g. Bakery → Client.bakery_id)
  • HasForeign — cross-persistence reference with user-provided resolution

Re-exports

pub use foreign::HasForeign;
pub use many::HasMany;
pub use one::HasOne;

Modules

foreign
HasForeign — cross-persistence reference with user-provided resolution.
many
HasMany — one-to-many relationship where the foreign key is on the target table.
one
HasOne — one-to-one relationship where the foreign key is on the source table.

Traits

Reference
Describes a relationship between two tables.